Documentation
¶
Index ¶
- type IObject1Mock
- func (m *IObject1Mock) MinimockFinish()
- func (m *IObject1Mock) MinimockStringDone() bool
- func (m *IObject1Mock) MinimockStringInspect()
- func (m *IObject1Mock) MinimockWait(timeout mm_time.Duration)
- func (mmString *IObject1Mock) String() (s1 string)
- func (mmString *IObject1Mock) StringAfterCounter() uint64
- func (mmString *IObject1Mock) StringBeforeCounter() uint64
- type IObject1MockStringExpectation
- type IObject1MockStringResults
- type IObject2Mock
- func (m *IObject2Mock) MinimockFinish()
- func (m *IObject2Mock) MinimockStringDone() bool
- func (m *IObject2Mock) MinimockStringInspect()
- func (m *IObject2Mock) MinimockWait(timeout mm_time.Duration)
- func (mmString *IObject2Mock) String() (s1 string)
- func (mmString *IObject2Mock) StringAfterCounter() uint64
- func (mmString *IObject2Mock) StringBeforeCounter() uint64
- type IObject2MockStringExpectation
- type IObject2MockStringResults
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IObject1Mock ¶
type IObject1Mock struct {
StringMock mIObject1MockString
// contains filtered or unexported fields
}
IObject1Mock implements mm_mainpkg.IObject1
func NewIObject1Mock ¶
func NewIObject1Mock(t minimock.Tester) *IObject1Mock
NewIObject1Mock returns a mock for mm_mainpkg.IObject1
func (*IObject1Mock) MinimockFinish ¶
func (m *IObject1Mock) MinimockFinish()
MinimockFinish checks that all mocked methods have been called the expected number of times
func (*IObject1Mock) MinimockStringDone ¶
func (m *IObject1Mock) MinimockStringDone() bool
MinimockStringDone returns true if the count of the String invocations corresponds the number of defined expectations
func (*IObject1Mock) MinimockStringInspect ¶
func (m *IObject1Mock) MinimockStringInspect()
MinimockStringInspect logs each unmet expectation
func (*IObject1Mock) MinimockWait ¶
func (m *IObject1Mock) MinimockWait(timeout mm_time.Duration)
MinimockWait waits for all mocked methods to be called the expected number of times
func (*IObject1Mock) String ¶
func (mmString *IObject1Mock) String() (s1 string)
String implements mm_mainpkg.IObject1
func (*IObject1Mock) StringAfterCounter ¶
func (mmString *IObject1Mock) StringAfterCounter() uint64
StringAfterCounter returns a count of finished IObject1Mock.String invocations
func (*IObject1Mock) StringBeforeCounter ¶
func (mmString *IObject1Mock) StringBeforeCounter() uint64
StringBeforeCounter returns a count of IObject1Mock.String invocations
type IObject1MockStringExpectation ¶
type IObject1MockStringExpectation struct {
Counter uint64
// contains filtered or unexported fields
}
IObject1MockStringExpectation specifies expectation struct of the IObject1.String
type IObject1MockStringResults ¶
type IObject1MockStringResults struct {
// contains filtered or unexported fields
}
IObject1MockStringResults contains results of the IObject1.String
type IObject2Mock ¶
type IObject2Mock struct {
StringMock mIObject2MockString
// contains filtered or unexported fields
}
IObject2Mock implements mm_mainpkg.IObject2
func NewIObject2Mock ¶
func NewIObject2Mock(t minimock.Tester) *IObject2Mock
NewIObject2Mock returns a mock for mm_mainpkg.IObject2
func (*IObject2Mock) MinimockFinish ¶
func (m *IObject2Mock) MinimockFinish()
MinimockFinish checks that all mocked methods have been called the expected number of times
func (*IObject2Mock) MinimockStringDone ¶
func (m *IObject2Mock) MinimockStringDone() bool
MinimockStringDone returns true if the count of the String invocations corresponds the number of defined expectations
func (*IObject2Mock) MinimockStringInspect ¶
func (m *IObject2Mock) MinimockStringInspect()
MinimockStringInspect logs each unmet expectation
func (*IObject2Mock) MinimockWait ¶
func (m *IObject2Mock) MinimockWait(timeout mm_time.Duration)
MinimockWait waits for all mocked methods to be called the expected number of times
func (*IObject2Mock) String ¶
func (mmString *IObject2Mock) String() (s1 string)
String implements mm_mainpkg.IObject2
func (*IObject2Mock) StringAfterCounter ¶
func (mmString *IObject2Mock) StringAfterCounter() uint64
StringAfterCounter returns a count of finished IObject2Mock.String invocations
func (*IObject2Mock) StringBeforeCounter ¶
func (mmString *IObject2Mock) StringBeforeCounter() uint64
StringBeforeCounter returns a count of IObject2Mock.String invocations
type IObject2MockStringExpectation ¶
type IObject2MockStringExpectation struct {
Counter uint64
// contains filtered or unexported fields
}
IObject2MockStringExpectation specifies expectation struct of the IObject2.String
type IObject2MockStringResults ¶
type IObject2MockStringResults struct {
// contains filtered or unexported fields
}
IObject2MockStringResults contains results of the IObject2.String